aboutsummaryrefslogtreecommitdiff
path: root/src/nix
diff options
context:
space:
mode:
Diffstat (limited to 'src/nix')
-rw-r--r--src/nix/develop.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/nix/develop.cc b/src/nix/develop.cc
index 8fea7ee9c..457d94382 100644
--- a/src/nix/develop.cc
+++ b/src/nix/develop.cc
@@ -474,9 +474,9 @@ struct CmdDevelop : Common, MixEnvironment
ignoreException();
}
// If running a phase, don't want an interactive shell running after
// Ctrl-C, so don't pass --rcfile
- auto args = phase ? Strings{std::string(baseNameOf(shell)), rcFilePath}
+ auto args = phase || !command.empty() ? Strings{std::string(baseNameOf(shell)), rcFilePath}
: Strings{std::string(baseNameOf(shell)), "--rcfile", rcFilePath};
restoreAffinity();
@@ -474,9 +474,9 @@ struct CmdDevelop : Common, MixEnvironment
ignoreException();
}
- // If running a phase, don't want an interactive shell running after
+ // If running a phase or single command, don't want an interactive shell running after
// Ctrl-C, so don't pass --rcfile